==> tastic-1.0.tar.gz: tastic-1.0/README.md <==
tastic
======

*Scripts and Command-Line tools for working with taskpaper documents on
macOS and iOS*.

Usage
=====

    Documentation for tastic can be found here: http://tastic.readthedocs.org/en/stable

    Usage:
        tastic index [-s <pathToSettingsFile>]

        -h, --help            show this help message
        -s, --settings        the settings file

Documentation
=============

Documentation for tastic is hosted by [Read the
Docs](http://tastic.readthedocs.org/en/stable/) (last [stable
version](http://tastic.readthedocs.org/en/stable/) and [latest
version](http://tastic.readthedocs.org/en/latest/)).

Installation
============

The easiest way to install tastic us to use `pip`:

    pip install tastic

Or you can clone the [github
repo](https://github.com/thespacedoctor/tastic) and install from a local
version of the code:

    git clone git@github.com:thespacedoctor/tastic.git
    cd tastic
    python setup.py install

To upgrade to the latest version of tastic use the command:

    pip install tastic --upgrade

Development
-----------

If you want to tinker with the code, then install in development mode.
This means you can modify the code from your cloned repo:

    git clone git@github.com:thespacedoctor/tastic.git
    cd tastic
    python setup.py develop

[Pull requests](https://github.com/thespacedoctor/tastic/pulls) are
welcomed!

Issues
------

Please report any issues
[here](https://github.com/thespacedoctor/tastic/issues).

License
=======

Copyright (c) 2016 David Young

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> tastic-1.0.2.tar.gz: tastic-1.0.2/README.md <==
tastic
======

*A python package for working with taskpaper documents*.

Usage
=====

    Documentation for tastic can be found here: http://tastic.readthedocs.org/en/stable

    Usage:
        tastic index [-s <pathToSettingsFile>]

        -h, --help            show this help message
        -s, --settings        the settings file

Documentation
=============

Documentation for tastic is hosted by [Read the
Docs](http://tastic-for-taskpaper.readthedocs.io/en/stable/) (last
[stable version](http://tastic-for-taskpaper.readthedocs.io/en/stable/)
and [latest
version](http://tastic-for-taskpaper.readthedocs.io/en/latest/)).

Installation
============

The easiest way to install tastic us to use `pip`:

    pip install tastic

Or you can clone the [github
repo](https://github.com/thespacedoctor/tastic) and install from a local
version of the code:

    git clone git@github.com:thespacedoctor/tastic.git
    cd tastic
    python setup.py install

To upgrade to the latest version of tastic use the command:

    pip install tastic --upgrade

Development
-----------

If you want to tinker with the code, then install in development mode.
This means you can modify the code from your cloned repo:

    git clone git@github.com:thespacedoctor/tastic.git
    cd tastic
    python setup.py develop

[Pull requests](https://github.com/thespacedoctor/tastic/pulls) are
welcomed!

Issues
------

Please report any issues
[here](https://github.com/thespacedoctor/tastic/issues).

License
=======

Copyright (c) 2016 David Young

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
